# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dex_k8s_client/dexidp/dex/api/v2_14_0.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dex_k8s_client/dexidp/dex/api/v2_14_0.proto',
  package='api',
  syntax='proto3',
  serialized_options=_b('\n\022com.coreos.dex.api'),
  serialized_pb=_b('\n+dex_k8s_client/dexidp/dex/api/v2_14_0.proto\x12\x03\x61pi\"\x82\x01\n\x06\x43lient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x15\n\rredirect_uris\x18\x03 \x03(\t\x12\x15\n\rtrusted_peers\x18\x04 \x03(\t\x12\x0e\n\x06public\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x10\n\x08logo_url\x18\x07 \x01(\t\".\n\x0f\x43reateClientReq\x12\x1b\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x0b.api.Client\"G\n\x10\x43reateClientResp\x12\x16\n\x0e\x61lready_exists\x18\x01 \x01(\x08\x12\x1b\n\x06\x63lient\x18\x02 \x01(\x0b\x32\x0b.api.Client\"\x1d\n\x0f\x44\x65leteClientReq\x12\n\n\x02id\x18\x01 \x01(\t\"%\n\x10\x44\x65leteClientResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08\"k\n\x0fUpdateClientReq\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rredirect_uris\x18\x02 \x03(\t\x12\x15\n\rtrusted_peers\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08logo_url\x18\x05 \x01(\t\"%\n\x10UpdateClientResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08\"J\n\x08Password\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\"4\n\x11\x43reatePasswordReq\x12\x1f\n\x08password\x18\x01 \x01(\x0b\x32\r.api.Password\",\n\x12\x43reatePasswordResp\x12\x16\n\x0e\x61lready_exists\x18\x01 \x01(\x08\"J\n\x11UpdatePasswordReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08new_hash\x18\x02 \x01(\x0c\x12\x14\n\x0cnew_username\x18\x03 \x01(\t\"\'\n\x12UpdatePasswordResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08\"\"\n\x11\x44\x65letePasswordReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"\'\n\x12\x44\x65letePasswordResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08\"\x11\n\x0fListPasswordReq\"4\n\x10ListPasswordResp\x12 \n\tpasswords\x18\x01 \x03(\x0b\x32\r.api.Password\"\x0c\n\nVersionReq\"*\n\x0bVersionResp\x12\x0e\n\x06server\x18\x01 \x01(\t\x12\x0b\n\x03\x61pi\x18\x02 \x01(\x05\"W\n\x0fRefreshTokenRef\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x11\n\tlast_used\x18\x06 \x01(\x03\"!\n\x0eListRefreshReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"?\n\x0fListRefreshResp\x12,\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32\x14.api.RefreshTokenRef\"6\n\x10RevokeRefreshReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\"&\n\x11RevokeRefreshResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08\x32\x82\x05\n\x03\x44\x65x\x12=\n\x0c\x43reateClient\x12\x14.api.CreateClientReq\x1a\x15.api.CreateClientResp\"\x00\x12=\n\x0cUpdateClient\x12\x14.api.UpdateClientReq\x1a\x15.api.UpdateClientResp\"\x00\x12=\n\x0c\x44\x65leteClient\x12\x14.api.DeleteClientReq\x1a\x15.api.DeleteClientResp\"\x00\x12\x43\n\x0e\x43reatePassword\x12\x16.api.CreatePasswordReq\x1a\x17.api.CreatePasswordResp\"\x00\x12\x43\n\x0eUpdatePassword\x12\x16.api.UpdatePasswordReq\x1a\x17.api.UpdatePasswordResp\"\x00\x12\x43\n\x0e\x44\x65letePassword\x12\x16.api.DeletePasswordReq\x1a\x17.api.DeletePasswordResp\"\x00\x12>\n\rListPasswords\x12\x14.api.ListPasswordReq\x1a\x15.api.ListPasswordResp\"\x00\x12\x31\n\nGetVersion\x12\x0f.api.VersionReq\x1a\x10.api.VersionResp\"\x00\x12:\n\x0bListRefresh\x12\x13.api.ListRefreshReq\x1a\x14.api.ListRefreshResp\"\x00\x12@\n\rRevokeRefresh\x12\x15.api.RevokeRefreshReq\x1a\x16.api.RevokeRefreshResp\"\x00\x42\x14\n\x12\x63om.coreos.dex.apib\x06proto3')
)




_CLIENT = _descriptor.Descriptor(
  name='Client',
  full_name='api.Client',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.Client.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret', full_name='api.Client.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redirect_uris', full_name='api.Client.redirect_uris', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trusted_peers', full_name='api.Client.trusted_peers', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public', full_name='api.Client.public', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='api.Client.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logo_url', full_name='api.Client.logo_url', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=183,
)


_CREATECLIENTREQ = _descriptor.Descriptor(
  name='CreateClientReq',
  full_name='api.CreateClientReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='api.CreateClientReq.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=231,
)


_CREATECLIENTRESP = _descriptor.Descriptor(
  name='CreateClientResp',
  full_name='api.CreateClientResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='already_exists', full_name='api.CreateClientResp.already_exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client', full_name='api.CreateClientResp.client', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=304,
)


_DELETECLIENTREQ = _descriptor.Descriptor(
  name='DeleteClientReq',
  full_name='api.DeleteClientReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.DeleteClientReq.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=335,
)


_DELETECLIENTRESP = _descriptor.Descriptor(
  name='DeleteClientResp',
  full_name='api.DeleteClientResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='not_found', full_name='api.DeleteClientResp.not_found', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=374,
)


_UPDATECLIENTREQ = _descriptor.Descriptor(
  name='UpdateClientReq',
  full_name='api.UpdateClientReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.UpdateClientReq.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redirect_uris', full_name='api.UpdateClientReq.redirect_uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trusted_peers', full_name='api.UpdateClientReq.trusted_peers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='api.UpdateClientReq.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logo_url', full_name='api.UpdateClientReq.logo_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=483,
)


_UPDATECLIENTRESP = _descriptor.Descriptor(
  name='UpdateClientResp',
  full_name='api.UpdateClientResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='not_found', full_name='api.UpdateClientResp.not_found', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=522,
)


_PASSWORD = _descriptor.Descriptor(
  name='Password',
  full_name='api.Password',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='api.Password.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='api.Password.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='api.Password.username', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='api.Password.user_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=524,
  serialized_end=598,
)


_CREATEPASSWORDREQ = _descriptor.Descriptor(
  name='CreatePasswordReq',
  full_name='api.CreatePasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='api.CreatePasswordReq.password', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=652,
)


_CREATEPASSWORDRESP = _descriptor.Descriptor(
  name='CreatePasswordResp',
  full_name='api.CreatePasswordResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='already_exists', full_name='api.CreatePasswordResp.already_exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=698,
)


_UPDATEPASSWORDREQ = _descriptor.Descriptor(
  name='UpdatePasswordReq',
  full_name='api.UpdatePasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='api.UpdatePasswordReq.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_hash', full_name='api.UpdatePasswordReq.new_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_username', full_name='api.UpdatePasswordReq.new_username', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=774,
)


_UPDATEPASSWORDRESP = _descriptor.Descriptor(
  name='UpdatePasswordResp',
  full_name='api.UpdatePasswordResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='not_found', full_name='api.UpdatePasswordResp.not_found', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=815,
)


_DELETEPASSWORDREQ = _descriptor.Descriptor(
  name='DeletePasswordReq',
  full_name='api.DeletePasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='api.DeletePasswordReq.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=817,
  serialized_end=851,
)


_DELETEPASSWORDRESP = _descriptor.Descriptor(
  name='DeletePasswordResp',
  full_name='api.DeletePasswordResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='not_found', full_name='api.DeletePasswordResp.not_found', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=892,
)


_LISTPASSWORDREQ = _descriptor.Descriptor(
  name='ListPasswordReq',
  full_name='api.ListPasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=911,
)


_LISTPASSWORDRESP = _descriptor.Descriptor(
  name='ListPasswordResp',
  full_name='api.ListPasswordResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='passwords', full_name='api.ListPasswordResp.passwords', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=913,
  serialized_end=965,
)


_VERSIONREQ = _descriptor.Descriptor(
  name='VersionReq',
  full_name='api.VersionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=979,
)


_VERSIONRESP = _descriptor.Descriptor(
  name='VersionResp',
  full_name='api.VersionResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='api.VersionResp.server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api', full_name='api.VersionResp.api', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1023,
)


_REFRESHTOKENREF = _descriptor.Descriptor(
  name='RefreshTokenRef',
  full_name='api.RefreshTokenRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.RefreshTokenRef.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='api.RefreshTokenRef.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='api.RefreshTokenRef.created_at', index=2,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_used', full_name='api.RefreshTokenRef.last_used', index=3,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1025,
  serialized_end=1112,
)


_LISTREFRESHREQ = _descriptor.Descriptor(
  name='ListRefreshReq',
  full_name='api.ListRefreshReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='api.ListRefreshReq.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1147,
)


_LISTREFRESHRESP = _descriptor.Descriptor(
  name='ListRefreshResp',
  full_name='api.ListRefreshResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='refresh_tokens', full_name='api.ListRefreshResp.refresh_tokens', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1149,
  serialized_end=1212,
)


_REVOKEREFRESHREQ = _descriptor.Descriptor(
  name='RevokeRefreshReq',
  full_name='api.RevokeRefreshReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='api.RevokeRefreshReq.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='api.RevokeRefreshReq.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1268,
)


_REVOKEREFRESHRESP = _descriptor.Descriptor(
  name='RevokeRefreshResp',
  full_name='api.RevokeRefreshResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='not_found', full_name='api.RevokeRefreshResp.not_found', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1270,
  serialized_end=1308,
)

_CREATECLIENTREQ.fields_by_name['client'].message_type = _CLIENT
_CREATECLIENTRESP.fields_by_name['client'].message_type = _CLIENT
_CREATEPASSWORDREQ.fields_by_name['password'].message_type = _PASSWORD
_LISTPASSWORDRESP.fields_by_name['passwords'].message_type = _PASSWORD
_LISTREFRESHRESP.fields_by_name['refresh_tokens'].message_type = _REFRESHTOKENREF
DESCRIPTOR.message_types_by_name['Client'] = _CLIENT
DESCRIPTOR.message_types_by_name['CreateClientReq'] = _CREATECLIENTREQ
DESCRIPTOR.message_types_by_name['CreateClientResp'] = _CREATECLIENTRESP
DESCRIPTOR.message_types_by_name['DeleteClientReq'] = _DELETECLIENTREQ
DESCRIPTOR.message_types_by_name['DeleteClientResp'] = _DELETECLIENTRESP
DESCRIPTOR.message_types_by_name['UpdateClientReq'] = _UPDATECLIENTREQ
DESCRIPTOR.message_types_by_name['UpdateClientResp'] = _UPDATECLIENTRESP
DESCRIPTOR.message_types_by_name['Password'] = _PASSWORD
DESCRIPTOR.message_types_by_name['CreatePasswordReq'] = _CREATEPASSWORDREQ
DESCRIPTOR.message_types_by_name['CreatePasswordResp'] = _CREATEPASSWORDRESP
DESCRIPTOR.message_types_by_name['UpdatePasswordReq'] = _UPDATEPASSWORDREQ
DESCRIPTOR.message_types_by_name['UpdatePasswordResp'] = _UPDATEPASSWORDRESP
DESCRIPTOR.message_types_by_name['DeletePasswordReq'] = _DELETEPASSWORDREQ
DESCRIPTOR.message_types_by_name['DeletePasswordResp'] = _DELETEPASSWORDRESP
DESCRIPTOR.message_types_by_name['ListPasswordReq'] = _LISTPASSWORDREQ
DESCRIPTOR.message_types_by_name['ListPasswordResp'] = _LISTPASSWORDRESP
DESCRIPTOR.message_types_by_name['VersionReq'] = _VERSIONREQ
DESCRIPTOR.message_types_by_name['VersionResp'] = _VERSIONRESP
DESCRIPTOR.message_types_by_name['RefreshTokenRef'] = _REFRESHTOKENREF
DESCRIPTOR.message_types_by_name['ListRefreshReq'] = _LISTREFRESHREQ
DESCRIPTOR.message_types_by_name['ListRefreshResp'] = _LISTREFRESHRESP
DESCRIPTOR.message_types_by_name['RevokeRefreshReq'] = _REVOKEREFRESHREQ
DESCRIPTOR.message_types_by_name['RevokeRefreshResp'] = _REVOKEREFRESHRESP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Client = _reflection.GeneratedProtocolMessageType('Client', (_message.Message,), dict(
  DESCRIPTOR = _CLIENT,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.Client)
  ))
_sym_db.RegisterMessage(Client)

CreateClientReq = _reflection.GeneratedProtocolMessageType('CreateClientReq', (_message.Message,), dict(
  DESCRIPTOR = _CREATECLIENTREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.CreateClientReq)
  ))
_sym_db.RegisterMessage(CreateClientReq)

CreateClientResp = _reflection.GeneratedProtocolMessageType('CreateClientResp', (_message.Message,), dict(
  DESCRIPTOR = _CREATECLIENTRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.CreateClientResp)
  ))
_sym_db.RegisterMessage(CreateClientResp)

DeleteClientReq = _reflection.GeneratedProtocolMessageType('DeleteClientReq', (_message.Message,), dict(
  DESCRIPTOR = _DELETECLIENTREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.DeleteClientReq)
  ))
_sym_db.RegisterMessage(DeleteClientReq)

DeleteClientResp = _reflection.GeneratedProtocolMessageType('DeleteClientResp', (_message.Message,), dict(
  DESCRIPTOR = _DELETECLIENTRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.DeleteClientResp)
  ))
_sym_db.RegisterMessage(DeleteClientResp)

UpdateClientReq = _reflection.GeneratedProtocolMessageType('UpdateClientReq', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECLIENTREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.UpdateClientReq)
  ))
_sym_db.RegisterMessage(UpdateClientReq)

UpdateClientResp = _reflection.GeneratedProtocolMessageType('UpdateClientResp', (_message.Message,), dict(
  DESCRIPTOR = _UPDATECLIENTRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.UpdateClientResp)
  ))
_sym_db.RegisterMessage(UpdateClientResp)

Password = _reflection.GeneratedProtocolMessageType('Password', (_message.Message,), dict(
  DESCRIPTOR = _PASSWORD,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.Password)
  ))
_sym_db.RegisterMessage(Password)

CreatePasswordReq = _reflection.GeneratedProtocolMessageType('CreatePasswordReq', (_message.Message,), dict(
  DESCRIPTOR = _CREATEPASSWORDREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.CreatePasswordReq)
  ))
_sym_db.RegisterMessage(CreatePasswordReq)

CreatePasswordResp = _reflection.GeneratedProtocolMessageType('CreatePasswordResp', (_message.Message,), dict(
  DESCRIPTOR = _CREATEPASSWORDRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.CreatePasswordResp)
  ))
_sym_db.RegisterMessage(CreatePasswordResp)

UpdatePasswordReq = _reflection.GeneratedProtocolMessageType('UpdatePasswordReq', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPASSWORDREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.UpdatePasswordReq)
  ))
_sym_db.RegisterMessage(UpdatePasswordReq)

UpdatePasswordResp = _reflection.GeneratedProtocolMessageType('UpdatePasswordResp', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEPASSWORDRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.UpdatePasswordResp)
  ))
_sym_db.RegisterMessage(UpdatePasswordResp)

DeletePasswordReq = _reflection.GeneratedProtocolMessageType('DeletePasswordReq', (_message.Message,), dict(
  DESCRIPTOR = _DELETEPASSWORDREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.DeletePasswordReq)
  ))
_sym_db.RegisterMessage(DeletePasswordReq)

DeletePasswordResp = _reflection.GeneratedProtocolMessageType('DeletePasswordResp', (_message.Message,), dict(
  DESCRIPTOR = _DELETEPASSWORDRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.DeletePasswordResp)
  ))
_sym_db.RegisterMessage(DeletePasswordResp)

ListPasswordReq = _reflection.GeneratedProtocolMessageType('ListPasswordReq', (_message.Message,), dict(
  DESCRIPTOR = _LISTPASSWORDREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.ListPasswordReq)
  ))
_sym_db.RegisterMessage(ListPasswordReq)

ListPasswordResp = _reflection.GeneratedProtocolMessageType('ListPasswordResp', (_message.Message,), dict(
  DESCRIPTOR = _LISTPASSWORDRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.ListPasswordResp)
  ))
_sym_db.RegisterMessage(ListPasswordResp)

VersionReq = _reflection.GeneratedProtocolMessageType('VersionReq', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.VersionReq)
  ))
_sym_db.RegisterMessage(VersionReq)

VersionResp = _reflection.GeneratedProtocolMessageType('VersionResp', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.VersionResp)
  ))
_sym_db.RegisterMessage(VersionResp)

RefreshTokenRef = _reflection.GeneratedProtocolMessageType('RefreshTokenRef', (_message.Message,), dict(
  DESCRIPTOR = _REFRESHTOKENREF,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.RefreshTokenRef)
  ))
_sym_db.RegisterMessage(RefreshTokenRef)

ListRefreshReq = _reflection.GeneratedProtocolMessageType('ListRefreshReq', (_message.Message,), dict(
  DESCRIPTOR = _LISTREFRESHREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.ListRefreshReq)
  ))
_sym_db.RegisterMessage(ListRefreshReq)

ListRefreshResp = _reflection.GeneratedProtocolMessageType('ListRefreshResp', (_message.Message,), dict(
  DESCRIPTOR = _LISTREFRESHRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.ListRefreshResp)
  ))
_sym_db.RegisterMessage(ListRefreshResp)

RevokeRefreshReq = _reflection.GeneratedProtocolMessageType('RevokeRefreshReq', (_message.Message,), dict(
  DESCRIPTOR = _REVOKEREFRESHREQ,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.RevokeRefreshReq)
  ))
_sym_db.RegisterMessage(RevokeRefreshReq)

RevokeRefreshResp = _reflection.GeneratedProtocolMessageType('RevokeRefreshResp', (_message.Message,), dict(
  DESCRIPTOR = _REVOKEREFRESHRESP,
  __module__ = 'dex_k8s_client.dexidp.dex.api.v2_14_0_pb2'
  # @@protoc_insertion_point(class_scope:api.RevokeRefreshResp)
  ))
_sym_db.RegisterMessage(RevokeRefreshResp)


DESCRIPTOR._options = None

_DEX = _descriptor.ServiceDescriptor(
  name='Dex',
  full_name='api.Dex',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1311,
  serialized_end=1953,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateClient',
    full_name='api.Dex.CreateClient',
    index=0,
    containing_service=None,
    input_type=_CREATECLIENTREQ,
    output_type=_CREATECLIENTRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateClient',
    full_name='api.Dex.UpdateClient',
    index=1,
    containing_service=None,
    input_type=_UPDATECLIENTREQ,
    output_type=_UPDATECLIENTRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteClient',
    full_name='api.Dex.DeleteClient',
    index=2,
    containing_service=None,
    input_type=_DELETECLIENTREQ,
    output_type=_DELETECLIENTRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePassword',
    full_name='api.Dex.CreatePassword',
    index=3,
    containing_service=None,
    input_type=_CREATEPASSWORDREQ,
    output_type=_CREATEPASSWORDRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePassword',
    full_name='api.Dex.UpdatePassword',
    index=4,
    containing_service=None,
    input_type=_UPDATEPASSWORDREQ,
    output_type=_UPDATEPASSWORDRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePassword',
    full_name='api.Dex.DeletePassword',
    index=5,
    containing_service=None,
    input_type=_DELETEPASSWORDREQ,
    output_type=_DELETEPASSWORDRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListPasswords',
    full_name='api.Dex.ListPasswords',
    index=6,
    containing_service=None,
    input_type=_LISTPASSWORDREQ,
    output_type=_LISTPASSWORDRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVersion',
    full_name='api.Dex.GetVersion',
    index=7,
    containing_service=None,
    input_type=_VERSIONREQ,
    output_type=_VERSIONRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListRefresh',
    full_name='api.Dex.ListRefresh',
    index=8,
    containing_service=None,
    input_type=_LISTREFRESHREQ,
    output_type=_LISTREFRESHRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeRefresh',
    full_name='api.Dex.RevokeRefresh',
    index=9,
    containing_service=None,
    input_type=_REVOKEREFRESHREQ,
    output_type=_REVOKEREFRESHRESP,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEX)

DESCRIPTOR.services_by_name['Dex'] = _DEX

# @@protoc_insertion_point(module_scope)
